@@ -14,11 +14,11 @@ else
     # should help avoid unwanted differences between containerized and
     # non-containerized trunk software sources.
     REPO_PREFIX=/etc/yum.repos.d
-    DELOREAN_REPO_URL=http://trunk.rdoproject.org/centos7/current-tripleo/
+    DELOREAN_REPO_URL=https://trunk.rdoproject.org/centos7/current-tripleo/
     DELOREAN_REPO_FILE=delorean.repo
 
     # Enable the Delorean Deps repository
-    curl -Lvo $REPO_PREFIX/delorean-deps.repo http://trunk.rdoproject.org/centos7/delorean-deps.repo
+    curl -Lvo $REPO_PREFIX/delorean-deps.repo https://trunk.rdoproject.org/centos7/delorean-deps.repo
     sed -i -e 's%priority=.*%priority=30%' $REPO_PREFIX/delorean-deps.repo
     cat $REPO_PREFIX/delorean-deps.repo
 
@@ -28,12 +28,12 @@ else
     cat $REPO_PREFIX/delorean.repo
 
     # Enable latest RDO Trunk Delorean repository
-    curl -Lvo $REPO_PREFIX/delorean-current.repo http://trunk.rdoproject.org/centos7/current/delorean.repo
+    curl -Lvo $REPO_PREFIX/delorean-current.repo https://trunk.rdoproject.org/centos7/current/delorean.repo
     sed -i -e 's%priority=.*%priority=10%' $REPO_PREFIX/delorean-current.repo
     sed -i 's/\[delorean\]/\[delorean-current\]/' $REPO_PREFIX/delorean-current.repo
     /bin/bash -c "cat <<-EOF>>$REPO_PREFIX/delorean-current.repo
 
-includepkgs=diskimage-builder,instack,instack-undercloud,os-apply-config,os-cloud-config,os-collect-config,os-net-config,os-refresh-config,python-tripleoclient,openstack-tripleo-common,openstack-tripleo-heat-templates,openstack-tripleo-image-elements,openstack-tripleo,openstack-tripleo-puppet-elements,openstack-puppet-modules,openstack-tripleo-ui,puppet-*
+includepkgs=diskimage-builder,instack,instack-undercloud,os-apply-config,os-collect-config,os-net-config,os-refresh-config,python-tripleoclient,openstack-tripleo-common,openstack-tripleo-heat-templates,openstack-tripleo-image-elements,openstack-tripleo,openstack-tripleo-puppet-elements,openstack-puppet-modules,openstack-tripleo-ui,puppet-*
 EOF"
     cat $REPO_PREFIX/delorean-current.repo
 
@@ -54,7 +54,11 @@ yum install -y \
         os-net-config \
         dhclient \
         ethtool \
-        python-heat-agent-* \
+        python-heat-agent-apply-config \
+        python-heat-agent-docker-cmd \
+        python-heat-agent-hiera \
+        python-heat-agent-puppet \
+        python-heat-agent-json-file \
         python-ipaddr \
         python-memcached \
         python2-oslo-log \
@@ -91,9 +95,16 @@ mkdir -p /etc/puppet/modules
 ln -sf /usr/share/openstack-puppet/modules/* /etc/puppet/modules/
 
 # And puppet hiera
+mkdir -p /usr/libexec/os-apply-config/templates/etc/puppet
+ln -sf /usr/share/tripleo-puppet-elements/hiera/os-apply-config/etc/puppet/hiera.yaml \
+    /usr/libexec/os-apply-config/templates/etc/puppet/
 ln -sf /etc/puppet/hiera.yaml /etc/hiera.yaml
 
 # Configure os-*
+ln -sf /usr/share/tripleo-puppet-elements/hiera/40-hiera-datafiles \
+    /usr/libexec/os-refresh-config/configure.d/
+ln -sf /usr/share/tripleo-puppet-elements/hiera/10-hiera-disable \
+    /usr/libexec/os-refresh-config/configure.d/
 mkdir -p /usr/libexec/os-refresh-config/post-configure.d
 ln -sf /usr/share/tripleo-image-elements/os-refresh-config/os-refresh-config/post-configure.d/99-refresh-completed \
     /usr/libexec/os-refresh-config/post-configure.d/
