@@ -48,15 +48,15 @@ class RegisterOrUpdateNodes(base.TripleOAction):
         self.kernel_name = kernel_name
         self.ramdisk_name = ramdisk_name
 
-    def run(self):
+    def run(self, context):
         for node in self.nodes_json:
             caps = node.get('capabilities', {})
             caps = nodes.capabilities_to_dict(caps)
             caps.setdefault('boot_option', self.instance_boot_option)
             node['capabilities'] = nodes.dict_to_capabilities(caps)
 
-        baremetal_client = self.get_baremetal_client()
-        image_client = self.get_image_client()
+        baremetal_client = self.get_baremetal_client(context)
+        image_client = self.get_image_client(context)
 
         try:
             return nodes.register_all_nodes(
@@ -71,6 +71,27 @@ class RegisterOrUpdateNodes(base.TripleOAction):
             return mistral_workflow_utils.Result(error=six.text_type(err))
 
 
+class ValidateNodes(base.TripleOAction):
+    """Validate Nodes Action
+
+    :param nodes_json: list of nodes & attributes in json format
+    """
+
+    def __init__(self, nodes_json):
+        super(ValidateNodes, self).__init__()
+        self.nodes_json = nodes_json
+
+    def run(self, context):
+        try:
+            nodes.validate_nodes(self.nodes_json)
+        except exception.InvalidNode as err:
+            LOG.error("Validation of nodes failed: %s", err)
+            return mistral_workflow_utils.Result(error=str(err))
+        except Exception as err:
+            LOG.exception("Unexpected exception during node validation")
+            return mistral_workflow_utils.Result(error=str(err))
+
+
 class ConfigureBootAction(base.TripleOAction):
     """Configure kernel and ramdisk.
 
@@ -89,9 +110,9 @@ class ConfigureBootAction(base.TripleOAction):
         self.ramdisk_name = ramdisk_name
         self.instance_boot_option = instance_boot_option
 
-    def run(self):
-        baremetal_client = self.get_baremetal_client()
-        image_client = self.get_image_client()
+    def run(self, context):
+        baremetal_client = self.get_baremetal_client(context)
+        image_client = self.get_image_client(context)
 
         try:
             image_ids = {'kernel': None, 'ramdisk': None}
@@ -155,17 +176,21 @@ class ConfigureRootDeviceAction(base.TripleOAction):
         self.minimum_size = minimum_size
         self.overwrite = overwrite
 
-    def run(self):
+    def run(self, context):
         if not self.root_device:
             return
 
-        baremetal_client = self.get_baremetal_client()
+        baremetal_client = self.get_baremetal_client(context)
         node = baremetal_client.node.get(self.node_uuid)
         self._apply_root_device_strategy(
-            node, self.root_device, self.minimum_size, self.overwrite)
+            node,
+            self.root_device,
+            self.minimum_size,
+            self.overwrite,
+            context=context)
 
     def _apply_root_device_strategy(self, node, strategy, minimum_size,
-                                    overwrite=False):
+                                    overwrite=False, context=None):
         if node.properties.get('root_device') and not overwrite:
             # This is a correct situation, we still want to allow people to
             # fine-tune the root device setting for a subset of nodes.
@@ -179,7 +204,7 @@ class ConfigureRootDeviceAction(base.TripleOAction):
                         node.uuid)
             return
 
-        inspector_client = self.get_baremetal_introspection_client()
+        inspector_client = self.get_baremetal_introspection_client(context)
         try:
             data = inspector_client.get_data(node.uuid)
         except ironic_inspector_client.ClientError:
@@ -227,7 +252,7 @@ class ConfigureRootDeviceAction(base.TripleOAction):
                     {'strategy': strategy, 'node': node.uuid})
 
         hint = None
-        for hint_name in ('wwn_with_extension', 'wwn', 'serial'):
+        for hint_name in ('wwn', 'serial'):
             if root_device.get(hint_name):
                 hint = {hint_name: root_device[hint_name]}
                 break
@@ -245,7 +270,7 @@ class ConfigureRootDeviceAction(base.TripleOAction):
         # This -1 is what we always do to account for partitioning
         new_size -= 1
 
-        bm_client = self.get_baremetal_client()
+        bm_client = self.get_baremetal_client(context)
         bm_client.node.update(
             node.uuid,
             [{'op': 'add', 'path': '/properties/root_device', 'value': hint},
@@ -273,8 +298,8 @@ class UpdateNodeCapability(base.TripleOAction):
         self.capability = capability
         self.value = value
 
-    def run(self):
-        baremetal_client = self.get_baremetal_client()
+    def run(self, context):
+        baremetal_client = self.get_baremetal_client(context)
 
         try:
             return nodes.update_node_capability(
@@ -297,7 +322,7 @@ class CellV2DiscoverHostsAction(base.TripleOAction):
 
     """
 
-    def run(self):
+    def run(self, context):
         try:
             result = nodes.run_nova_cell_v2_discovery()
             LOG.info(
@@ -310,3 +335,17 @@ class CellV2DiscoverHostsAction(base.TripleOAction):
             return mistral_workflow_utils.Result(
                 error="%s: %s" % (type(err).__name__, str(err))
             )
+
+
+class GetProfileAction(base.TripleOAction):
+    """Return the profile associated with the given node """
+
+    def __init__(self, node):
+        super(GetProfileAction, self).__init__()
+        self.node = node
+
+    def run(self, context):
+        result = {}
+        result['profile'] = nodes.get_node_profile(self.node)
+        result['uuid'] = self.node.get('uuid')
+        return result
