@@ -33,36 +33,23 @@ class ClearBreakpointsAction(base.TripleOAction):
         self.stack_id = stack_id
         self.refs = refs
 
-    def run(self):
-        heat = self.get_orchestration_client()
-        nova = self.get_compute_client()
+    def run(self, context):
+        heat = self.get_orchestration_client(context)
+        nova = self.get_compute_client(context)
         update_manager = PackageUpdateManager(
             heat, nova, self.stack_id, stack_fields={})
         update_manager.clear_breakpoints(self.refs)
 
 
-class CancelStackUpdateAction(base.TripleOAction):
-    def __init__(self, stack_id):
-        super(CancelStackUpdateAction, self).__init__()
-        self.stack_id = stack_id
-
-    def run(self):
-        heat = self.get_orchestration_client()
-        nova = self.get_compute_client()
-        update_manager = PackageUpdateManager(
-            heat, nova, self.stack_id, stack_fields={})
-        update_manager.cancel()
-
-
 class UpdateStackAction(templates.ProcessTemplatesAction):
 
     def __init__(self, timeout, container=constants.DEFAULT_CONTAINER_NAME):
         super(UpdateStackAction, self).__init__(container)
         self.timeout_mins = timeout
 
-    def run(self):
+    def run(self, context):
         # get the stack. Error if doesn't exist
-        heat = self.get_orchestration_client()
+        heat = self.get_orchestration_client(context)
         try:
             stack = heat.stacks.get(self.container)
         except heat_exc.HTTPNotFound:
@@ -76,7 +63,7 @@ class UpdateStackAction(templates.ProcessTemplatesAction):
         parameters['UpdateIdentifier'] = timestamp
         parameters['StackAction'] = 'UPDATE'
 
-        wc = self.get_workflow_client()
+        wc = self.get_workflow_client(context)
         try:
             wf_env = wc.environments.get(self.container)
         except Exception:
@@ -96,7 +83,7 @@ class UpdateStackAction(templates.ProcessTemplatesAction):
         wc.environments.update(**env_kwargs)
 
         # process all plan files and create or update a stack
-        processed_data = super(UpdateStackAction, self).run()
+        processed_data = super(UpdateStackAction, self).run(context)
 
         # If we receive a 'Result' instance it is because the parent action
         # had an error.
