@@ -27,6 +27,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import logging
+import uuid
 
 from heatclient import exc as heat_exc
 from mistral.workflow import utils as mistral_workflow_utils
@@ -44,14 +45,16 @@ LOG = logging.getLogger(__name__)
 class GetParametersAction(templates.ProcessTemplatesAction):
     """Gets list of available heat parameters."""
 
-    def run(self):
+    def run(self, context):
 
-        cached = self.cache_get(self.container, "tripleo.parameters.get")
+        cached = self.cache_get(context,
+                                self.container,
+                                "tripleo.parameters.get")
 
         if cached is not None:
             return cached
 
-        processed_data = super(GetParametersAction, self).run()
+        processed_data = super(GetParametersAction, self).run(context)
 
         # If we receive a 'Result' instance it is because the parent action
         # had an error.
@@ -61,9 +64,9 @@ class GetParametersAction(templates.ProcessTemplatesAction):
         processed_data['show_nested'] = True
 
         # respect previously user set param values
-        wc = self.get_workflow_client()
+        wc = self.get_workflow_client(context)
         wf_env = wc.environments.get(self.container)
-        orc = self.get_orchestration_client()
+        orc = self.get_orchestration_client(context)
 
         params = wf_env.variables.get('parameter_defaults')
 
@@ -77,7 +80,10 @@ class GetParametersAction(templates.ProcessTemplatesAction):
             'heat_resource_tree': orc.stacks.validate(**fields),
             'mistral_environment_parameters': params,
         }
-        self.cache_set(self.container, "tripleo.parameters.get", result)
+        self.cache_set(context,
+                       self.container,
+                       "tripleo.parameters.get",
+                       result)
         return result
 
 
@@ -88,8 +94,8 @@ class ResetParametersAction(base.TripleOAction):
         super(ResetParametersAction, self).__init__()
         self.container = container
 
-    def run(self):
-        wc = self.get_workflow_client()
+    def run(self, context):
+        wc = self.get_workflow_client(context)
         wf_env = wc.environments.get(self.container)
 
         if 'parameter_defaults' in wf_env.variables:
@@ -100,7 +106,9 @@ class ResetParametersAction(base.TripleOAction):
             'variables': wf_env.variables
         }
         wc.environments.update(**env_kwargs)
-        self.cache_delete(self.container, "tripleo.parameters.get")
+        self.cache_delete(context,
+                          self.container,
+                          "tripleo.parameters.get")
         return wf_env
 
 
@@ -113,8 +121,8 @@ class UpdateParametersAction(base.TripleOAction):
         self.container = container
         self.parameters = parameters
 
-    def run(self):
-        wc = self.get_workflow_client()
+    def run(self, context):
+        wc = self.get_workflow_client(context)
         wf_env = wc.environments.get(self.container)
         if 'parameter_defaults' not in wf_env.variables:
             wf_env.variables['parameter_defaults'] = {}
@@ -124,7 +132,9 @@ class UpdateParametersAction(base.TripleOAction):
             'variables': wf_env.variables
         }
         wc.environments.update(**env_kwargs)
-        self.cache_delete(self.container, "tripleo.parameters.get")
+        self.cache_delete(context,
+                          self.container,
+                          "tripleo.parameters.get")
         return wf_env
 
 
@@ -136,12 +146,12 @@ class UpdateRoleParametersAction(UpdateParametersAction):
                                                          container=container)
         self.role = role
 
-    def run(self):
-        baremetal_client = self.get_baremetal_client()
-        compute_client = self.get_compute_client()
+    def run(self, context):
+        baremetal_client = self.get_baremetal_client(context)
+        compute_client = self.get_compute_client(context)
         self.parameters = parameters.set_count_and_flavor_params(
             self.role, baremetal_client, compute_client)
-        return super(UpdateRoleParametersAction, self).run()
+        return super(UpdateRoleParametersAction, self).run(context)
 
 
 class GeneratePasswordsAction(base.TripleOAction):
@@ -156,10 +166,10 @@ class GeneratePasswordsAction(base.TripleOAction):
         super(GeneratePasswordsAction, self).__init__()
         self.container = container
 
-    def run(self):
+    def run(self, context):
 
-        orchestration = self.get_orchestration_client()
-        wc = self.get_workflow_client()
+        orchestration = self.get_orchestration_client(context)
+        wc = self.get_workflow_client(context)
         try:
             wf_env = wc.environments.get(self.container)
         except Exception:
@@ -191,7 +201,9 @@ class GeneratePasswordsAction(base.TripleOAction):
         }
 
         wc.environments.update(**env_kwargs)
-        self.cache_delete(self.container, "tripleo.parameters.get")
+        self.cache_delete(context,
+                          self.container,
+                          "tripleo.parameters.get")
 
         return wf_env.variables['passwords']
 
@@ -208,8 +220,8 @@ class GetPasswordsAction(base.TripleOAction):
         super(GetPasswordsAction, self).__init__()
         self.container = container
 
-    def run(self):
-        wc = self.get_workflow_client()
+    def run(self, context):
+        wc = self.get_workflow_client(context)
         try:
             wf_env = wc.environments.get(self.container)
         except Exception:
@@ -249,10 +261,10 @@ class GenerateFencingParametersAction(base.TripleOAction):
         self.ipmi_cipher = ipmi_cipher
         self.ipmi_lanplus = ipmi_lanplus
 
-    def run(self):
+    def run(self, context):
         """Returns the parameters for fencing controller nodes"""
-        hostmap = nodes.generate_hostmap(self.get_baremetal_client(),
-                                         self.get_compute_client())
+        hostmap = nodes.generate_hostmap(self.get_baremetal_client(context),
+                                         self.get_compute_client(context))
         fence_params = {"EnableFencing": True, "FencingConfig": {}}
         devices = []
 
@@ -286,7 +298,8 @@ class GenerateFencingParametersAction(base.TripleOAction):
                      "bm_name": hostmap[mac_addr]["baremetal_name"]})
                 if self.delay:
                     params["delay"] = self.delay
-            elif node["pm_type"].split('_')[1] in ("ipmitool", "ilo", "drac"):
+            elif (node['pm_type'] == 'ipmi' or node["pm_type"].split('_')[1] in
+                  ("ipmitool", "ilo", "drac")):
                 # IPMI fencing driver
                 node_data["agent"] = "fence_ipmilan"
                 if self.fence_action:
@@ -315,3 +328,71 @@ class GenerateFencingParametersAction(base.TripleOAction):
 
         fence_params["FencingConfig"]["devices"] = devices
         return {"parameter_defaults": fence_params}
+
+
+class GetFlattenedParametersAction(GetParametersAction):
+    """Get the heat stack tree and parameters in flattened structure.
+
+    This method validates the stack of the container and returns the
+    parameters and the heat stack tree. The heat stack tree is flattened
+    for easy consumption.
+    """
+
+    def __init__(self, container=constants.DEFAULT_CONTAINER_NAME):
+        super(GetFlattenedParametersAction, self).__init__(container)
+
+    def _processParams(self, flattened, params):
+        for item in params:
+            if item not in flattened['parameters']:
+                param_obj = {}
+                for key, value in params.get(item).items():
+                    camel_case_key = key[0].lower() + key[1:]
+                    param_obj[camel_case_key] = value
+                param_obj['name'] = item
+                flattened['parameters'][item] = param_obj
+        return list(params)
+
+    def _process(self, flattened, name, data):
+        key = str(uuid.uuid4())
+        value = {}
+        value.update({
+            'name': name,
+            'id': key
+        })
+        if 'Type' in data:
+            value['type'] = data['Type']
+        if 'Description' in data:
+            value['description'] = data['Description']
+        if 'Parameters' in data:
+            value['parameters'] = self._processParams(flattened,
+                                                      data['Parameters'])
+        if 'NestedParameters' in data:
+            nested = data['NestedParameters']
+            nested_ids = []
+            for nested_key in nested.keys():
+                nested_data = self._process(flattened, nested_key,
+                                            nested.get(nested_key))
+                # nested_data will always have one key (and only one)
+                nested_ids.append(list(nested_data)[0])
+
+            value['resources'] = nested_ids
+
+        flattened['resources'][key] = value
+        return {key: value}
+
+    def run(self, context):
+        # process all plan files and create or update a stack
+        processed_data = super(GetFlattenedParametersAction, self).run(context)
+
+        # If we receive a 'Result' instance it is because the parent action
+        # had an error.
+        if isinstance(processed_data, mistral_workflow_utils.Result):
+            return processed_data
+
+        if processed_data['heat_resource_tree']:
+            flattened = {'resources': {}, 'parameters': {}}
+            self._process(flattened, 'Root',
+                          processed_data['heat_resource_tree'])
+            processed_data['heat_resource_tree'] = flattened
+
+        return processed_data
