@@ -21,7 +21,6 @@ import six
 from six import reraise as raise_
 
 from tripleo_common.i18n import _
-from tripleo_common.i18n import _LE
 
 _FATAL_EXCEPTION_FORMAT_ERRORS = False
 
@@ -47,9 +46,9 @@ class TripleoCommonException(Exception):
             exc_info = sys.exc_info()
             # kwargs doesn't match a variable in the message
             # log the issue and the kwargs
-            LOG.exception(_LE('Exception in string format operation'))
-            for name, value in six.iteritems(kwargs):
-                LOG.error(_LE("%(name)s: %(value)s"),
+            LOG.exception('Exception in string format operation')
+            for name, value in kwargs.items():
+                LOG.error("%(name)s: %(value)s",
                           {'name': name, 'value': value})  # noqa
 
             if _FATAL_EXCEPTION_FORMAT_ERRORS:
@@ -103,3 +102,7 @@ class StateTransitionFailed(Exception):
 
 class RootDeviceDetectionError(Exception):
     """Failed to detect the root device"""
+
+
+class PlanOperationError(Exception):
+    """Error while performing a deployment plan operation"""
