@@ -125,6 +125,42 @@ class PrefixedDriverInfoTestWithPort(base.TestCase):
                          self.driver_info.unique_id_from_node(node))
 
 
+class RedfishDriverInfoTest(base.TestCase):
+    driver_info = nodes.RedfishDriverInfo()
+
+    def test_convert_key(self):
+        keys = {'pm_addr': 'redfish_address',
+                'pm_user': 'redfish_username',
+                'pm_password': 'redfish_password',
+                'pm_system_id': 'redfish_system_id',
+                'redfish_verify_ca': 'redfish_verify_ca'}
+        for key, expected in keys.items():
+            self.assertEqual(expected, self.driver_info.convert_key(key))
+
+        self.assertIsNone(self.driver_info.convert_key('unknown'))
+
+    def test_unique_id_from_fields(self):
+        for address in ['example.com',
+                        'http://example.com/',
+                        'https://example.com/']:
+            fields = {'pm_addr': address,
+                      'pm_user': 'user',
+                      'pm_password': '123456',
+                      'pm_system_id': '/redfish/v1/Systems/1'}
+            self.assertEqual('example.com/redfish/v1/Systems/1',
+                             self.driver_info.unique_id_from_fields(fields))
+
+    def test_unique_id_from_node(self):
+        for address in ['example.com',
+                        'http://example.com/',
+                        'https://example.com/']:
+            node = mock.Mock(driver_info={
+                'redfish_address': address,
+                'redfish_system_id': '/redfish/v1/Systems/1'})
+            self.assertEqual('example.com/redfish/v1/Systems/1',
+                             self.driver_info.unique_id_from_node(node))
+
+
 class iBootDriverInfoTest(base.TestCase):
     def setUp(self):
         super(iBootDriverInfoTest, self).setUp()
@@ -167,6 +203,7 @@ class FindNodeHandlerTest(base.TestCase):
                 ('fake_pxe', 'fake'),
                 ('pxe_ssh', 'ssh'),
                 ('pxe_ipmitool', 'ipmi'),
+                ('ipmi', 'ipmi'),
                 ('pxe_ilo', 'ilo'),
                 ('agent_irmc', 'irmc')]
         for driver, prefix in test:
@@ -390,6 +427,9 @@ class NodesTest(base.TestCase):
         ironic.node.update.assert_called_once_with(
             ironic.node.get.return_value.uuid, mock.ANY)
 
+    def test_update_node_ironic_ipmi(self):
+        self._update_by_type('ipmi')
+
     def test_update_node_ironic_pxe_ipmitool(self):
         self._update_by_type('pxe_ipmitool')
 
@@ -402,6 +442,17 @@ class NodesTest(base.TestCase):
     def test_update_node_ironic_pxe_irmc(self):
         self._update_by_type('pxe_irmc')
 
+    def test_update_node_ironic_redfish(self):
+        ironic = mock.MagicMock()
+        node_map = {'mac': {}, 'pm_addr': {}}
+        node = self._get_node()
+        node.update({'pm_type': 'redfish',
+                     'pm_system_id': '/path'})
+        node_map['pm_addr']['foo.bar/path'] = ironic.node.get.return_value.uuid
+        nodes._update_or_register_ironic_node(node, node_map, client=ironic)
+        ironic.node.update.assert_called_once_with(
+            ironic.node.get.return_value.uuid, mock.ANY)
+
     def test_register_node_update(self):
         node = self._get_node()
         node['mac'][0] = node['mac'][0].upper()
@@ -509,6 +560,22 @@ class NodesTest(base.TestCase):
             driver_info={'ucs_password': 'random', 'ucs_address': 'foo.bar',
                          'ucs_username': 'test'})
 
+    def test_register_ironic_node_ipmi(self):
+        node_properties = {"cpus": "1",
+                           "memory_mb": "2048",
+                           "local_gb": "30",
+                           "cpu_arch": "amd64",
+                           "capabilities": "num_nics:6"}
+        node = self._get_node()
+        node['pm_type'] = 'ipmi'
+        node['pm_port'] = '6230'
+        client = mock.MagicMock()
+        nodes.register_ironic_node(node, client=client)
+        client.node.create.assert_called_once_with(
+            driver='ipmi', name='node1', properties=node_properties,
+            driver_info={'ipmi_password': 'random', 'ipmi_address': 'foo.bar',
+                         'ipmi_username': 'test', 'ipmi_port': '6230'})
+
     def test_register_ironic_node_pxe_ipmitool(self):
         node_properties = {"cpus": "1",
                            "memory_mb": "2048",
@@ -541,6 +608,24 @@ class NodesTest(base.TestCase):
             driver_info={'drac_password': 'random', 'drac_host': 'foo.bar',
                          'drac_username': 'test', 'drac_port': '6230'})
 
+    def test_register_ironic_node_redfish(self):
+        node_properties = {"cpus": "1",
+                           "memory_mb": "2048",
+                           "local_gb": "30",
+                           "cpu_arch": "amd64",
+                           "capabilities": "num_nics:6"}
+        node = self._get_node()
+        node['pm_type'] = 'redfish'
+        node['pm_system_id'] = '/redfish/v1/Systems/1'
+        client = mock.MagicMock()
+        nodes.register_ironic_node(node, client=client)
+        client.node.create.assert_called_once_with(
+            driver='redfish', name='node1', properties=node_properties,
+            driver_info={'redfish_password': 'random',
+                         'redfish_address': 'foo.bar',
+                         'redfish_username': 'test',
+                         'redfish_system_id': '/redfish/v1/Systems/1'})
+
     def test_register_ironic_node_update_int_values(self):
         node = self._get_node()
         ironic = mock.MagicMock()
@@ -612,12 +697,12 @@ class TestPopulateNodeMapping(base.TestCase):
         node1 = ironic_node('abcdef', 'pxe_ssh', None)
         node2 = ironic_node('fedcba', 'pxe_ipmitool',
                             {'ipmi_address': '10.0.1.2'})
-        client.node.list_ports.side_effect = ([ironic_port('aaa')],
-                                              [])
-        client.node.list.return_value = [node1, node2]
+        node3 = ironic_node('xyz', 'ipmi', {'ipmi_address': '10.0.1.3'})
+        client.node.list_ports.side_effect = ([ironic_port('aaa')], [], [])
+        client.node.list.return_value = [node1, node2, node3]
         expected = {'mac': {'aaa': 'abcdef'},
-                    'pm_addr': {'10.0.1.2': 'fedcba'},
-                    'uuids': {'abcdef', 'fedcba'}}
+                    'pm_addr': {'10.0.1.2': 'fedcba', '10.0.1.3': 'xyz'},
+                    'uuids': {'abcdef', 'fedcba', 'xyz'}}
         self.assertEqual(expected, nodes._populate_node_mapping(client))
 
     def test_populate_node_mapping_ironic_fake_pxe(self):
@@ -631,3 +716,214 @@ class TestPopulateNodeMapping(base.TestCase):
         expected = {'mac': {'aaa': 'abcdef'}, 'pm_addr': {},
                     'uuids': {'abcdef'}}
         self.assertEqual(expected, nodes._populate_node_mapping(client))
+
+
+EXAMPLE_SSH_PRIVATE_KEY = """
+-----BEGIN RSA PRIVATE KEY-----
+ABCDEF
+-----END RSA PRIVATE KEY-----
+"""
+
+
+VALID_NODE_JSON = [
+    {'_comment': 'This is a comment',
+     'pm_type': 'pxe_ipmitool',
+     'pm_addr': '192.168.0.1',
+     'pm_user': 'root',
+     'pm_password': 'p@$$w0rd'},
+    {'pm_type': 'ipmi',
+     'pm_addr': '192.168.1.1',
+     'pm_user': 'root',
+     'pm_password': 'p@$$w0rd'},
+    {'pm_type': 'pxe_ipmitool',
+     'pm_addr': '192.168.0.1',
+     'pm_user': 'root',
+     'pm_password': 'p@$$w0rd',
+     'pm_port': 1234,
+     'ipmi_priv_level': 'USER',
+     'mac': ['aa:bb:cc:dd:ee:ff',
+             '11:22:33:44:55:66'],
+     'name': 'foobar1',
+     'capabilities': {'foo': 'bar'},
+     'kernel_id': 'kernel1',
+     'ramdisk_id': 'ramdisk1'},
+    {'pm_type': 'ipmi',
+     'pm_addr': '192.168.1.1',
+     'pm_user': 'root',
+     'pm_password': 'p@$$w0rd',
+     'pm_port': 1234,
+     'ipmi_priv_level': 'USER',
+     'mac': ['dd:ee:ff:aa:bb:cc',
+             '44:55:66:11:22:33'],
+     'name': 'foobar2',
+     'capabilities': {'foo': 'bar'},
+     'kernel_id': 'kernel1',
+     'ramdisk_id': 'ramdisk1'},
+    {'pm_type': 'pxe_ssh',
+     'pm_addr': '1.2.3.4',
+     'pm_user': 'root',
+     'pm_password': EXAMPLE_SSH_PRIVATE_KEY,
+     '_comment': 'This is another comment',
+     'mac': ['11:11:11:11:11:11']},
+    {'pm_type': 'pxe_ssh',
+     'pm_addr': '1.2.3.4',
+     'pm_user': 'root',
+     'pm_password': EXAMPLE_SSH_PRIVATE_KEY,
+     'mac': ['22:22:22:22:22:22'],
+     'capabilities': 'foo:bar,foo1:bar1',
+     'cpu': 2,
+     'memory': 1024,
+     'disk': 40,
+     'arch': 'x86_64'},
+    {'pm_type': 'redfish',
+     'pm_addr': '1.2.3.4',
+     'pm_user': 'root',
+     'pm_password': 'foobar',
+     'pm_system_id': '/redfish/v1/Systems/1'},
+]
+
+
+class TestValidateNodes(base.TestCase):
+    def test_valid(self):
+        nodes.validate_nodes(VALID_NODE_JSON)
+
+    def test_unknown_driver(self):
+        nodes_json = [
+            {'pm_type': 'pxe_foobar',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd'},
+        ]
+        self.assertRaisesRegex(exception.InvalidNode,
+                               'unknown pm_type .* pxe_foobar',
+                               nodes.validate_nodes, nodes_json)
+
+    def test_duplicate_ipmi_address(self):
+        nodes_json = [
+            {'pm_type': 'pxe_ipmitool',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd'},
+            {'pm_type': 'ipmi',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'user',
+             'pm_password': 'p@$$w0rd'},
+        ]
+        self.assertRaisesRegex(exception.InvalidNode,
+                               'Node identified by 1.1.1.1 is already present',
+                               nodes.validate_nodes, nodes_json)
+
+    def test_invalid_mac(self):
+        nodes_json = [
+            {'pm_type': 'pxe_ipmitool',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd',
+             'mac': ['42']},
+        ]
+        self.assertRaisesRegex(exception.InvalidNode,
+                               'MAC address 42 is invalid',
+                               nodes.validate_nodes, nodes_json)
+
+    def test_duplicate_mac(self):
+        nodes_json = [
+            {'pm_type': 'pxe_ipmitool',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd',
+             'mac': ['11:22:33:44:55:66']},
+            {'pm_type': 'ipmi',
+             'pm_addr': '1.2.1.1',
+             'pm_user': 'user',
+             'pm_password': 'p@$$w0rd',
+             'mac': ['11:22:33:44:55:66']},
+        ]
+        self.assertRaisesRegex(exception.InvalidNode,
+                               'MAC 11:22:33:44:55:66 is not unique',
+                               nodes.validate_nodes, nodes_json)
+
+    def test_duplicate_names(self):
+        nodes_json = [
+            {'pm_type': 'pxe_ipmitool',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd',
+             'name': 'name'},
+            {'pm_type': 'pxe_ipmitool',
+             'pm_addr': '1.2.1.2',
+             'pm_user': 'user',
+             'pm_password': 'p@$$w0rd',
+             'name': 'name'},
+        ]
+        self.assertRaisesRegex(exception.InvalidNode,
+                               'Name "name" is not unique',
+                               nodes.validate_nodes, nodes_json)
+
+    def test_invalid_capability(self):
+        nodes_json = [
+            {'pm_type': 'pxe_ipmitool',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd',
+             'capabilities': '42'},
+        ]
+        self.assertRaisesRegex(exception.InvalidNode,
+                               'Invalid capabilities: 42',
+                               nodes.validate_nodes, nodes_json)
+
+    def test_unexpected_fields(self):
+        nodes_json = [
+            {'pm_type': 'pxe_ipmitool',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd',
+             'pm_foobar': '42'},
+        ]
+        self.assertRaisesRegex(exception.InvalidNode,
+                               'Unknown field pm_foobar',
+                               nodes.validate_nodes, nodes_json)
+
+    def test_missing_fields(self):
+        for field in ('pm_addr', 'pm_user', 'pm_password'):
+            nodes_json = [
+                {'pm_type': 'pxe_ipmitool',
+                 'pm_addr': '1.1.1.1',
+                 'pm_user': 'root',
+                 'pm_password': 'p@$$w0rd'},
+            ]
+            del nodes_json[0][field]
+
+            self.assertRaisesRegex(exception.InvalidNode,
+                                   'fields are missing: %s' % field,
+                                   nodes.validate_nodes, nodes_json)
+
+    def test_duplicate_redfish_node(self):
+        nodes_json = [
+            {'pm_type': 'redfish',
+             'pm_addr': 'example.com',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd',
+             'pm_system_id': '/redfish/v1/Systems/1'},
+            {'pm_type': 'redfish',
+             'pm_addr': 'https://example.com',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd',
+             'pm_system_id': '/redfish/v1/Systems/1'},
+        ]
+        self.assertRaisesRegex(
+            exception.InvalidNode,
+            'Node identified by example.com/redfish/v1/Systems/1 '
+            'is already present',
+            nodes.validate_nodes, nodes_json)
+
+    def test_redfish_missing_system_id(self):
+        nodes_json = [
+            {'pm_type': 'redfish',
+             'pm_addr': '1.1.1.1',
+             'pm_user': 'root',
+             'pm_password': 'p@$$w0rd'},
+        ]
+
+        self.assertRaisesRegex(exception.InvalidNode,
+                               'fields are missing: pm_system_id',
+                               nodes.validate_nodes, nodes_json)
