@@ -135,6 +135,40 @@ class PrefixedDriverInfo(DriverInfo):
         return result
 
 
+class RedfishDriverInfo(DriverInfo):
+    def __init__(self):
+        mapping = {
+            'pm_addr': 'redfish_address',
+            'pm_user': 'redfish_username',
+            'pm_password': 'redfish_password',
+            'pm_system_id': 'redfish_system_id'
+        }
+        mandatory_fields = list(mapping)
+
+        super(RedfishDriverInfo, self).__init__(
+            'redfish', mapping,
+            deprecated_mapping=None,
+            mandatory_fields=mandatory_fields,
+        )
+
+    def _build_id(self, address, system):
+        address = re.sub(r'https?://', '', address, count=1, flags=re.I)
+        return '%s/%s' % (address.rstrip('/'), system.lstrip('/'))
+
+    def unique_id_from_fields(self, fields):
+        try:
+            return self._build_id(fields['pm_addr'], fields['pm_system_id'])
+        except KeyError:
+            return
+
+    def unique_id_from_node(self, node):
+        try:
+            return self._build_id(node.driver_info['redfish_address'],
+                                  node.driver_info['redfish_system_id'])
+        except KeyError:
+            return
+
+
 class SshDriverInfo(DriverInfo):
     DEFAULTS = {'ssh_virt_type': 'virsh'}
 
@@ -189,7 +223,7 @@ class iBootDriverInfo(PrefixedDriverInfo):
 
 DRIVER_INFO = {
     # production drivers
-    '.*_ipmi(tool|native)': PrefixedDriverInfo('ipmi', has_port=True),
+    '(ipmi|.*_ipmitool)': PrefixedDriverInfo('ipmi', has_port=True),
     '.*_drac': PrefixedDriverInfo('drac', address_field='host',
                                   has_port=True),
     '.*_ilo': PrefixedDriverInfo('ilo'),
@@ -206,6 +240,7 @@ DRIVER_INFO = {
             'pm_sensor_method': 'irmc_sensor_method',
             'pm_deploy_iso': 'irmc_deploy_iso',
         }),
+    'redfish': RedfishDriverInfo(),
     # test drivers
     '.*_ssh': SshDriverInfo(),
     '.*_iboot': iBootDriverInfo(),
@@ -432,6 +467,9 @@ def validate_nodes(nodes_list):
     names = set()
     macs = set()
     for index, node in enumerate(nodes_list):
+        # Remove any comment
+        node.pop("_comment", None)
+
         handler = _find_node_handler(node)
 
         try:
@@ -550,3 +588,15 @@ def run_nova_cell_v2_discovery():
         'discover_hosts',
         '--verbose'
     )
+
+
+def get_node_profile(node):
+    """Return the profile assosicated with the node """
+
+    capabilities = node.get('properties').get('capabilities')
+    capabilities_dict = capabilities_to_dict(capabilities)
+
+    if 'profile' in capabilities_dict:
+        return capabilities_dict['profile']
+
+    return None
